@@ -13,7 +13,9 @@
 makeHosakiFunction = function() {
   makeSingleObjectiveFunction(
     name = "Hosaki Function",
+    id = "hosaki_2d",
     fn = function(x) {
+      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
       (1 - 8 * x[1] + 7 * x[1]^2 - 7 * x[1]^3 / 3 + 0.25 * x[1]^4) * x[2]^2 * exp(-x[2])
     },
     par.set = makeNumericParamSet(
@@ -30,6 +32,6 @@ makeHosakiFunction = function() {
 }
 
 class(makeHosakiFunction) = c("function", "smoof_generator")
-attr(makeHosakiFunction, "name") = c("Hosaki Function")
+attr(makeHosakiFunction, "name") = c("Hosaki")
 attr(makeHosakiFunction, "type") = c("single-objective")
-attr(makeHosakiFunction, "tags") = c("continuous", "differentiable", "non-separable", "non-scalable", "multimodal")
+attr(makeHosakiFunction, "tags") = c("single-objective", "continuous", "differentiable", "non-separable", "non-scalable", "multimodal")
