@@ -8,8 +8,9 @@ test_that("single-objective test function generators work", {
     all.methods = setdiff(all.methods, c("makeInternalObjectiveFunction",
       "makeMultiObjectiveFunction", "makeObjectiveFunction",
       "makeSingleObjectiveFunction", "makeBBOBFunction",
+      "makeShekelFunction",
       "makeUFFunction", "makeUFParamSet", "makeMPM2Function",
-      "makeGOMOPFunction", paste0("makeMOP", 1:7, "Function")))
+      "makeGOMOPFunction", paste0("makeMOP", 1:7, "Function"), "makeHartmannFunction"))
     all.methods = sapply(all.methods, get)
     fun.generators = Filter(function(fun) inherits(fun, "smoof_generator"), all.methods)
 
